@@ -3,7 +3,8 @@ from django.contrib import admin
 
 from .views import (change_book, delete_book,
     view_that_raises, view_with_object, view_with_permission_list,
-    BookUpdateView, BookDeleteView, ViewThatRaises, ViewWithPermissionList)
+    BookUpdateView, BookDeleteView, ViewThatRaises, ViewWithPermissionList,
+    BookUpdateErrorView)
 
 admin.autodiscover()
 
@@ -22,4 +23,6 @@ urlpatterns = [
     url(r'^cbv/(?P<book_id>\d+)/delete/$', BookDeleteView.as_view(), name='cbv.delete_book'),
     url(r'^cbv/(?P<book_id>\d+)/raise/$', ViewThatRaises.as_view(), name='cbv.view_that_raises'),
     url(r'^cbv/(?P<book_id>\d+)/list/$', ViewWithPermissionList.as_view(), name='cbv.view_with_permission_list'),
+
+    url(r'^cbv/(?P<book_id>\d+)/change-error/$', BookUpdateErrorView.as_view(), name='cbv.change_book_error'),
 ]
