@@ -3,20 +3,17 @@ from __future__ import absolute_import
 from django.core.exceptions import ImproperlyConfigured
 from django.http import HttpRequest, Http404
 from django.test import TestCase
+from django.urls import reverse
 from django.utils.encoding import force_str
 
-try:
-    from django.urls import reverse
-except ImportError:
-    # Django < 2.0
-    from django.core.urlresolvers import reverse
-
 from rules.contrib.views import objectgetter
 
 from testapp.models import Book
 
+from . import TestData
 
-class FBVDecoratorTests(TestCase):
+
+class FBVDecoratorTests(TestData, TestCase):
     def test_objectgetter(self):
         request = HttpRequest()
         book = Book.objects.get(pk=1)
@@ -92,7 +89,12 @@ class FBVDecoratorTests(TestCase):
         self.assertEqual(response.status_code, 302)
 
 
-class CBVMixinTests(TestCase):
+class CBVMixinTests(TestData, TestCase):
+    def test_get_object_error(self):
+        self.assertTrue(self.client.login(username='adrian', password='secr3t'))
+        with self.assertRaises(AttributeError):
+            self.client.get(reverse('cbv.change_book_error', args=(1,)))
+
     def test_permission_required_mixin(self):
         # Adrian can change his book
         self.assertTrue(self.client.login(username='adrian', password='secr3t'))
@@ -112,10 +114,11 @@ class CBVMixinTests(TestCase):
         self.assertEqual(response.status_code, 200)
         self.assertEqual(force_str(response.content), 'OK')
 
-        # Martin can *not* delete Adrian's book and is redirected to login
+        # Martin can *not* delete Adrian's book
+        # Up to Django v2.1, the response was a redirect to login
         self.assertTrue(self.client.login(username='martin', password='secr3t'))
         response = self.client.get(reverse('cbv.delete_book', args=(1,)))
-        self.assertEqual(response.status_code, 302)
+        self.assertIn(response.status_code, [302, 403])
 
         # Martin can *not* delete Adrian's book and an PermissionDenied is raised
         self.assertTrue(self.client.login(username='martin', password='secr3t'))
@@ -131,6 +134,7 @@ class CBVMixinTests(TestCase):
         self.assertEqual(force_str(response.content), 'OK')
 
         # Martin does not have delete permission
+        # Up to Django v2.1, the response was a redirect to login
         self.assertTrue(self.client.login(username='martin', password='secr3t'))
         response = self.client.get(reverse('cbv.view_with_permission_list', args=(1,)))
-        self.assertEqual(response.status_code, 302)
+        self.assertIn(response.status_code, [302, 403])
